@@ -5,12 +5,16 @@ import sys
 
 import agate
 import agatesql  # noqa: F401
-from pkg_resources import iter_entry_points
 from sqlalchemy import create_engine, dialects
 
 from csvkit.cli import CSVKitUtility, isatty
 
-DIALECTS = dialects.__all__ + tuple(e.name for e in iter_entry_points('sqlalchemy.dialects'))
+try:
+    import importlib_metadata
+except ImportError:
+    import importlib.metadata as importlib_metadata
+
+DIALECTS = dialects.__all__ + tuple(e.name for e in importlib_metadata.entry_points(group='sqlalchemy.dialects'))
 
 
 class CSVSQL(CSVKitUtility):
@@ -79,7 +83,7 @@ class CSVSQL(CSVKitUtility):
             help='Chunk size for batch insert into the table. Requires --insert.')
 
     def main(self):
-        if isatty(sys.stdin) and not self.args.input_paths:
+        if isatty(sys.stdin) and self.args.input_paths == ['-']:
             self.argparser.error('You must provide an input file or piped data.')
 
         self.input_files = []
@@ -134,7 +138,7 @@ class CSVSQL(CSVKitUtility):
                     "trying to use. Available backends include:\n\nPostgreSQL:\tpip install psycopg2\nMySQL:\t\tpip "
                     "install mysql-connector-python OR pip install mysqlclient\n\nFor details on connection strings "
                     "and other backends, please see the SQLAlchemy documentation on dialects at:\n\n"
-                    "http://www.sqlalchemy.org/docs/dialects/\n\n"
+                    "https://www.sqlalchemy.org/docs/dialects/\n\n"
                 ) from e
 
             self.connection = engine.connect()
@@ -147,6 +151,7 @@ class CSVSQL(CSVKitUtility):
 
             if self.connection:
                 self.connection.close()
+                engine.dispose()
 
     def _failsafe_main(self):
         """
@@ -176,7 +181,7 @@ class CSVSQL(CSVKitUtility):
                     skip_lines=self.args.skip_lines,
                     sniff_limit=sniff_limit,
                     column_types=self.get_column_types(),
-                    **self.reader_kwargs
+                    **self.reader_kwargs,
                 )
             except StopIteration:
                 # Catch cases where no table data was provided and fall through
@@ -187,7 +192,7 @@ class CSVSQL(CSVKitUtility):
                 if self.connection:
                     if self.args.before_insert:
                         for query in self.args.before_insert.split(';'):
-                            self.connection.execute(query)
+                            self.connection.exec_driver_sql(query)
 
                     table.to_sql(
                         self.connection,
@@ -200,12 +205,12 @@ class CSVSQL(CSVKitUtility):
                         db_schema=self.args.db_schema,
                         constraints=not self.args.no_constraints,
                         unique_constraint=self.unique_constraint,
-                        chunk_size=self.args.chunk_size
+                        chunk_size=self.args.chunk_size,
                     )
 
                     if self.args.after_insert:
                         for query in self.args.after_insert.split(';'):
-                            self.connection.execute(query)
+                            self.connection.exec_driver_sql(query)
 
                 # Output SQL statements
                 else:
@@ -214,10 +219,10 @@ class CSVSQL(CSVKitUtility):
                         dialect=self.args.dialect,
                         db_schema=self.args.db_schema,
                         constraints=not self.args.no_constraints,
-                        unique_constraint=self.unique_constraint
+                        unique_constraint=self.unique_constraint,
                     )
 
-                    self.output_file.write('%s\n' % statement)
+                    self.output_file.write(f'{statement}\n')
 
         if self.connection:
             if self.args.queries:
@@ -233,7 +238,7 @@ class CSVSQL(CSVKitUtility):
 
                 for query in queries:
                     if query.strip():
-                        rows = self.connection.execute(query)
+                        rows = self.connection.exec_driver_sql(query)
 
                 # Output the result of the last query as CSV
                 if rows.returns_rows:
