@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 import unittest
 
 from csvkit.cleanup import join_rows
@@ -8,11 +6,11 @@ from csvkit.cleanup import join_rows
 class TestCleanup(unittest.TestCase):
 
     def test_fix_rows(self):
-        """Test to ensure that row merging yields correct results"""
-        start = [['1', '2', '3', ],
+        """Test to ensure that row merging yields correct results."""
+        start = [['1', '2', '3'],
                  [''],
                  ['abc'],
-                 ['4', '5']
+                 ['4', '5'],
                  ]
         fixed = join_rows(start)
         self.assertEqual(4, len(fixed))
