@@ -1,8 +1,6 @@
-#!/usr/bin/env python
-
+import io
 import os
 import sys
-from io import StringIO
 from textwrap import dedent
 from unittest.mock import patch
 
@@ -24,10 +22,8 @@ class TestCSVSQL(CSVKitTestCase, EmptyFileTests):
         self.db_file = 'foo.db'
 
     def tearDown(self):
-        try:
+        if os.path.exists(self.db_file):
             os.remove(self.db_file)
-        except OSError:
-            pass
 
     def test_create_table(self):
         sql = self.get_output(['--tables', 'foo', 'examples/testfixed_converted.csv'])
@@ -112,7 +108,7 @@ class TestCSVSQL(CSVKitTestCase, EmptyFileTests):
         '''))  # noqa: W291
 
     def test_stdin(self):
-        input_file = StringIO('a,b,c\n4,2,3\n')
+        input_file = io.BytesIO(b'a,b,c\n4,2,3\n')
 
         with stdin_as_string(input_file):
             sql = self.get_output(['--tables', 'foo'])
@@ -128,7 +124,7 @@ class TestCSVSQL(CSVKitTestCase, EmptyFileTests):
         input_file.close()
 
     def test_stdin_and_filename(self):
-        input_file = StringIO("a,b,c\n1,2,3\n")
+        input_file = io.BytesIO(b'a,b,c\n1,2,3\n')
 
         with stdin_as_string(input_file):
             sql = self.get_output(['-', 'examples/dummy.csv'])
@@ -139,7 +135,7 @@ class TestCSVSQL(CSVKitTestCase, EmptyFileTests):
         input_file.close()
 
     def test_query(self):
-        input_file = StringIO("a,b,c\n1,2,3\n")
+        input_file = io.BytesIO(b'a,b,c\n1,2,3\n')
 
         with stdin_as_string(input_file):
             sql = self.get_output(['--query', 'SELECT m.usda_id, avg(i.sepal_length) AS mean_sepal_length FROM iris '
@@ -154,7 +150,7 @@ class TestCSVSQL(CSVKitTestCase, EmptyFileTests):
         input_file.close()
 
     def test_query_empty(self):
-        input_file = StringIO()
+        input_file = io.BytesIO()
 
         with stdin_as_string(input_file):
             output = self.get_output(['--query', 'SELECT 1'])
@@ -189,14 +185,14 @@ class TestCSVSQL(CSVKitTestCase, EmptyFileTests):
                          'SELECT 1; CREATE TABLE foobar (date DATE)', '--after-insert',
                          'INSERT INTO dummy VALUES (0, 5, 6)'])
 
-        output_file = StringIO()
+        output_file = io.StringIO()
         utility = SQL2CSV(['--db', 'sqlite:///' + self.db_file, '--query', 'SELECT * FROM foobar'], output_file)
         utility.run()
         output = output_file.getvalue()
         output_file.close()
         self.assertEqual(output, 'date\n')
 
-        output_file = StringIO()
+        output_file = io.StringIO()
         utility = SQL2CSV(['--db', 'sqlite:///' + self.db_file, '--query', 'SELECT * FROM dummy'], output_file)
         utility.run()
         output = output_file.getvalue()
