@@ -1,5 +1,4 @@
-#!/usr/bin/env python
-
+import json
 import sys
 from unittest.mock import patch
 
@@ -78,14 +77,14 @@ class TestCSVStat(CSVKitTestCase, ColumnsTests, EmptyFileTests, NamesTests):
         header = next(reader)
 
         self.assertEqual(header[1], 'column_name')
-        self.assertEqual(header[4], 'unique')
+        self.assertEqual(header[5], 'unique')
 
         row = next(reader)
 
         self.assertEqual(row[1], 'state')
         self.assertEqual(row[2], 'Text')
-        self.assertEqual(row[5], '')
-        self.assertEqual(row[11], '2')
+        self.assertEqual(row[6], '')
+        self.assertEqual(row[12], '2')
 
     def test_csv_columns(self):
         output = self.get_output_as_io(['--csv', '-c', '4', 'examples/realdata/ks_1033_data.csv'])
@@ -95,14 +94,48 @@ class TestCSVStat(CSVKitTestCase, ColumnsTests, EmptyFileTests, NamesTests):
         header = next(reader)
 
         self.assertEqual(header[1], 'column_name')
-        self.assertEqual(header[4], 'unique')
+        self.assertEqual(header[5], 'unique')
 
         row = next(reader)
 
         self.assertEqual(row[1], 'nsn')
         self.assertEqual(row[2], 'Text')
-        self.assertEqual(row[5], '')
-        self.assertEqual(row[11], '16')
+        self.assertEqual(row[6], '')
+        self.assertEqual(row[12], '16')
+
+    def test_json(self):
+        output = self.get_output_as_io(['--json', 'examples/realdata/ks_1033_data.csv'])
+
+        data = json.load(output)
+
+        header = list(data[0])
+
+        self.assertEqual(header[1], 'column_name')
+        self.assertEqual(header[5], 'unique')
+
+        row = list(data[0].values())
+
+        self.assertEqual(row[1], 'state')
+        self.assertEqual(row[2], 'Text')
+        self.assertNotIn('min', data[0])
+        self.assertEqual(row[-2], 2.0)
+
+    def test_json_columns(self):
+        output = self.get_output_as_io(['--json', '-c', '4', 'examples/realdata/ks_1033_data.csv'])
+
+        data = json.load(output)
+
+        header = list(data[0])
+
+        self.assertEqual(header[1], 'column_name')
+        self.assertEqual(header[5], 'unique')
+
+        row = list(data[0].values())
+
+        self.assertEqual(row[1], 'nsn')
+        self.assertEqual(row[2], 'Text')
+        self.assertNotIn('min', data[0])
+        self.assertEqual(row[-2], 16.0)
 
     def test_decimal_format(self):
         output = self.get_output(['-c', 'TOTAL', '--mean', 'examples/realdata/FY09_EDU_Recipients_by_State.csv'])
@@ -110,13 +143,13 @@ class TestCSVStat(CSVKitTestCase, ColumnsTests, EmptyFileTests, NamesTests):
         self.assertEqual(output, '9,748.346\n')
 
         output = self.get_output([
-            '-c', 'TOTAL', '--mean', '--no-grouping-separator', 'examples/realdata/FY09_EDU_Recipients_by_State.csv'
+            '-c', 'TOTAL', '--mean', '--no-grouping-separator', 'examples/realdata/FY09_EDU_Recipients_by_State.csv',
         ])
 
         self.assertEqual(output, '9748.346\n')
 
         output = self.get_output([
-            '-c', 'TOTAL', '--mean', '--decimal-format', '%.2f', 'examples/realdata/FY09_EDU_Recipients_by_State.csv'
+            '-c', 'TOTAL', '--mean', '--decimal-format', '%.2f', 'examples/realdata/FY09_EDU_Recipients_by_State.csv',
         ])
 
         self.assertEqual(output, '9,748.35\n')
