@@ -1,8 +1,6 @@
-#!/usr/bin/env python
-
+import io
 import os
 import sys
-from io import StringIO
 from unittest.mock import patch
 
 from csvkit.utilities.in2csv import In2CSV, launch_new_instance
@@ -39,6 +37,28 @@ class TestIn2CSV(CSVKitTestCase, EmptyFileTests):
     def test_blanks(self):
         self.assertConverted('csv', 'examples/blanks.csv', 'examples/blanks.csv', ['--blanks'])
 
+    def test_null_value(self):
+        input_file = io.BytesIO(b'a,b\nn/a,\\N')
+
+        with stdin_as_string(input_file):
+            self.assertLines(['-f', 'csv', '--null-value', '\\N'], [
+                'a,b',
+                ',',
+            ])
+
+        input_file.close()
+
+    def test_null_value_blanks(self):
+        input_file = io.BytesIO(b'a,b\nn/a,\\N')
+
+        with stdin_as_string(input_file):
+            self.assertLines(['-f', 'csv', '--null-value', '\\N', '--blanks'], [
+                'a,b',
+                'n/a,',
+            ])
+
+        input_file.close()
+
     def test_date_format(self):
         self.assertConverted('csv', 'examples/test_date_format.csv',
                              'examples/test_date_format_converted.csv', ['--date-format', '%d/%m/%Y'])
@@ -133,7 +153,7 @@ class TestIn2CSV(CSVKitTestCase, EmptyFileTests):
                              ['--no-header-row', '--no-inference', '--snifflimit', '0'])
 
     def test_csv_datetime_inference(self):
-        input_file = StringIO('a\n2015-01-01T00:00:00Z')
+        input_file = io.BytesIO(b'a\n2015-01-01T00:00:00Z')
 
         with stdin_as_string(input_file):
             self.assertLines(['-f', 'csv'], [
@@ -162,9 +182,9 @@ class TestIn2CSV(CSVKitTestCase, EmptyFileTests):
         ])
 
     def test_geojson_no_inference(self):
-        input_file = StringIO(
-            '{"a": 1, "b": 2, "type": "FeatureCollection", "features": [{"geometry": {}, "properties": '
-            '{"a": 1, "b": 2, "c": 3}}]}')
+        input_file = io.BytesIO(
+            b'{"a": 1, "b": 2, "type": "FeatureCollection", "features": [{"geometry": {}, "properties": '
+            b'{"a": 1, "b": 2, "c": 3}}]}')
 
         with stdin_as_string(input_file):
             self.assertLines(['--no-inference', '-f', 'geojson'], [
@@ -175,7 +195,7 @@ class TestIn2CSV(CSVKitTestCase, EmptyFileTests):
         input_file.close()
 
     def test_json_no_inference(self):
-        input_file = StringIO('[{"a": 1, "b": 2, "c": 3}]')
+        input_file = io.BytesIO(b'[{"a": 1, "b": 2, "c": 3}]')
 
         with stdin_as_string(input_file):
             self.assertLines(['--no-inference', '-f', 'json'], [
@@ -186,7 +206,7 @@ class TestIn2CSV(CSVKitTestCase, EmptyFileTests):
         input_file.close()
 
     def test_ndjson_no_inference(self):
-        input_file = StringIO('{"a": 1, "b": 2, "c": 3}')
+        input_file = io.BytesIO(b'{"a": 1, "b": 2, "c": 3}')
 
         with stdin_as_string(input_file):
             self.assertLines(['--no-inference', '-f', 'ndjson'], [
@@ -212,12 +232,10 @@ class TestIn2CSV(CSVKitTestCase, EmptyFileTests):
         try:
             self.assertConverted('xls', 'examples/sheets.xls', 'examples/testxls_converted.csv',
                                  ['--sheet', 'data', '--write-sheets', "ʤ,1"])
-            with open('examples/sheets_0.csv') as f:
-                with open('examples/testxls_unicode_converted.csv') as g:
-                    self.assertEqual(f.read(), g.read())
-            with open('examples/sheets_1.csv') as f:
-                with open('examples/testxls_converted.csv') as g:
-                    self.assertEqual(f.read(), g.read())
+            with open('examples/sheets_0.csv') as f, open('examples/testxls_unicode_converted.csv') as g:
+                self.assertEqual(f.read(), g.read())
+            with open('examples/sheets_1.csv') as f, open('examples/testxls_converted.csv') as g:
+                self.assertEqual(f.read(), g.read())
             self.assertFalse(os.path.exists('examples/sheets_2.csv'))
         finally:
             for suffix in (0, 1):
@@ -229,15 +247,51 @@ class TestIn2CSV(CSVKitTestCase, EmptyFileTests):
         try:
             self.assertConverted('xlsx', 'examples/sheets.xlsx', 'examples/testxlsx_noinference_converted.csv',
                                  ['--no-inference', '--sheet', 'data', '--write-sheets', "ʤ,1"])
-            with open('examples/sheets_0.csv') as f:
-                with open('examples/testxlsx_unicode_converted.csv') as g:
-                    self.assertEqual(f.read(), g.read())
-            with open('examples/sheets_1.csv') as f:
-                with open('examples/testxlsx_noinference_converted.csv') as g:
-                    self.assertEqual(f.read(), g.read())
+            with open('examples/sheets_0.csv') as f, open('examples/testxlsx_unicode_converted.csv') as g:
+                self.assertEqual(f.read(), g.read())
+            with open('examples/sheets_1.csv') as f, open('examples/testxlsx_noinference_converted.csv') as g:
+                self.assertEqual(f.read(), g.read())
             self.assertFalse(os.path.exists('examples/sheets_2.csv'))
         finally:
             for suffix in (0, 1):
                 path = 'examples/sheets_%d.csv' % suffix
                 if os.path.exists(path):
                     os.remove(path)
+
+    def test_convert_xls_with_write_sheets_with_names(self):
+        try:
+            self.assertConverted('xls', 'examples/sheets.xls', 'examples/testxls_converted.csv',
+                                 ['--sheet', 'data', '--write-sheets', "ʤ,1", '--use-sheet-names'])
+            with open('examples/sheets_ʤ.csv', 'r') as f:
+                with open('examples/testxls_unicode_converted.csv', 'r') as g:
+                    self.assertEqual(f.read(), g.read())
+            with open('examples/sheets_data.csv', 'r') as f:
+                with open('examples/testxls_converted.csv', 'r') as g:
+                    self.assertEqual(f.read(), g.read())
+            self.assertFalse(os.path.exists('examples/sheets_0.csv'))
+            self.assertFalse(os.path.exists('examples/sheets_1.csv'))
+            self.assertFalse(os.path.exists('examples/sheets_2.csv'))
+        finally:
+            for suffix in ('ʤ', 'data'):
+                path = 'examples/sheets_%s.csv' % suffix
+                if os.path.exists(path):
+                    os.remove(path)
+
+    def test_convert_xlsx_with_write_sheets_with_names(self):
+        try:
+            self.assertConverted('xlsx', 'examples/sheets.xlsx', 'examples/testxlsx_noinference_converted.csv',
+                                 ['--no-inference', '--sheet', 'data', '--write-sheets', "ʤ,1", '--use-sheet-names'])
+            with open('examples/sheets_ʤ.csv', 'r') as f:
+                with open('examples/testxlsx_unicode_converted.csv', 'r') as g:
+                    self.assertEqual(f.read(), g.read())
+            with open('examples/sheets_data.csv', 'r') as f:
+                with open('examples/testxlsx_noinference_converted.csv', 'r') as g:
+                    self.assertEqual(f.read(), g.read())
+            self.assertFalse(os.path.exists('examples/sheets_0.csv'))
+            self.assertFalse(os.path.exists('examples/sheets_1.csv'))
+            self.assertFalse(os.path.exists('examples/sheets_2.csv'))
+        finally:
+            for suffix in ('ʤ', 'data'):
+                path = 'examples/sheets_%s.csv' % suffix
+                if os.path.exists(path):
+                    os.remove(path)
